//
// FUNKVIEW.H - The class definition for TMyApp.
//
//  Copyright (C) Borland International, 1991.
//

//
// class FunkyView
//      View that simply displays some text on the screen in a random color.
//
// Member functions:
//      FunkyView - Constructor
//      ~FunkyView - Destructor
//      draw - Display the text
//      getPalette - To have a color to display the text in.
//
//    for stream support:
//      FunkyView - stream constructor
//      streamableName
//      build
//      read
//      write
//

class FunkyView : public TView
{

public:

    FunkyView( TRect& r, char *word );
    virtual ~FunkyView() { delete text; }
    virtual void draw();
    virtual TPalette& getPalette() const;

private:

    char *text;

// Stream support is from here on down. //

    virtual const char *streamableName() const
        { return name; }

protected:

    virtual void write( opstream& op );
    virtual void *read( ipstream& ip );

public:

    FunkyView( StreamableInit ) : TView( streamableInit ) { }
    static TStreamable *build();

    static const char * const name;

};

inline ipstream& operator >> ( ipstream& is, FunkyView& cl )
    { return is >> (TStreamable&) cl; }
inline ipstream& operator >> ( ipstream& is, FunkyView*& cl )
    { return is >> (void *&) cl; }

inline opstream& operator << ( opstream& os, FunkyView& cl )
    { return os << (TStreamable&) cl; }
inline opstream& operator << ( opstream& os, FunkyView* cl )
    { return os << (TStreamable *) cl; }


//
// FunkyWindow - provides encapsulation for FunkyView, as well as the
//   ability to move the view around the screen and remove it from the
//   desktop with little coding (since TWindow's automatically call cmClose)
//
// Member functions:
//      FunkyWindow - Constructor
//      sizeLimits - so we can have a smaller than regulation TWindow.
//
//    for stream support:
//      FunkyWindow - stream constructor
//      streamableName
//      build
//      read
//      write
//

#define FUNK_WIDTH  33
#define FUNK_HEIGHT  5


#pragma argsused

class FunkyWindow : public TWindow
{

public:

    FunkyWindow( TRect& r, char *words);
    virtual void sizeLimits( TPoint& min, TPoint& )
        { min.x = FUNK_WIDTH; min.y = FUNK_HEIGHT; }

// Stream support is from here on down. //

    virtual const char *streamableName() const
        { return name; }

protected:

//    virtual void write( opstream& op );       // These will be inherited.
//    virtual void *read( ipstream& ip );

public:

    FunkyWindow( StreamableInit ) : TWindow( streamableInit ),
                                    TWindowInit( streamableInit ) { }
    static TStreamable *build();

    static const char * const name;

};

inline ipstream& operator >> ( ipstream& is, FunkyWindow& cl )
    { return is >> (TStreamable&) cl; }
inline ipstream& operator >> ( ipstream& is, FunkyWindow*& cl )
    { return is >> (void *&) cl; }

inline opstream& operator << ( opstream& os, FunkyWindow& cl )
    { return os << (TStreamable&) cl; }
inline opstream& operator << ( opstream& os, FunkyWindow* cl )
    { return os << (TStreamable *) cl; }
